# Lens Grove CLI
A command line interface for the Lens Grove storage network.

# What is Lens?
[Lens](https://lens.xyz) is an onchain social network. Their latest iteration features a storage network called Grove that can store any file below 125MB in size. This CLI allows you to leverage Grove to store and share small files.

# How do I use this?
You can install it with pip: `pip install lens-grove-cli`
I would recommend using pipx instead of pip because it manages virtual environments for you.

The command explains its usage. The base command is lens-grove-cli.

If you want to use the same database on multiple computers, the database is stored in `[your user folder]/.littlebitstudios/grove_cli/database.yaml`.

# Security Warning
***Do not use any Ethereum wallets that you care about with this CLI tool, as the private keys are stored in plaintext on your computer.*** If someone gets access to a wallet generated by this tool for exclusive use with Grove, the worst they could do is delete or edit your files, or post stuff on your Lens Account if you allowed one of the wallets to manage it (but managers are easy to revoke).

# License
This project is licensed under the MIT license.
